==> drd-8.x-3.0.tar.gz: drd/src/Plugin/Block/WidgetGlobalActions.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\drd\RemoteActions;

/**
 * Provides a 'WidgetGlobalActions' block.
 *
 * @Block(
 *  id = "drd_global_actions",
 *  admin_label = @Translation("DRD Global actions"),
 *  weight = -5,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetGlobalActions extends Base {

  /**
   * Drupal\drd\RemoteActions definition.
   *
   * @var \Drupal\drd\RemoteActions
   */
  protected $drdRemoteActions;

  /**
   * Construct.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   */
  public function __construct(
        array $configuration,
        $plugin_id,
        $plugin_definition,
        RemoteActions $drd_remote_actions
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->drdRemoteActions = $drd_remote_actions;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('drd.remote.actions')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    $build['drd_global_actions'] = \Drupal::formBuilder()->getForm('Drupal\drd\Form\Actions');

    return $build;
  }

}

==> drd-8.x-3.3.tar.gz: drd/src/Plugin/Block/WidgetGlobalActions.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\drd\RemoteActions;

/**
 * Provides a 'WidgetGlobalActions' block.
 *
 * @Block(
 *  id = "drd_global_actions",
 *  admin_label = @Translation("DRD Global actions"),
 *  weight = -5,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetGlobalActions extends WidgetBase {

  /**
   * Drupal\drd\RemoteActions definition.
   *
   * @var \Drupal\drd\RemoteActions
   */
  protected $drdRemoteActions;

  /**
   * Construct.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   */
  public function __construct(
        array $configuration,
        $plugin_id,
        $plugin_definition,
        RemoteActions $drd_remote_actions
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->drdRemoteActions = $drd_remote_actions;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('drd.remote.actions')
    );
  }

  protected function title() {
    return $this->t('Action');
  }

  protected function message() {
    return \Drupal::formBuilder()->getForm('Drupal\drd\Form\Actions');
  }

}
